@@ -285,13 +285,21 @@ class Firefox:
 
     def get(
         self,
-        url: str
+        url: str,
+        force: bool = False
     ) -> bool:
-        clean_current = self.driver.current_url.replace('https://', '').replace('www.', '').strip('/')
-        clean_new = url.replace('https://', '').replace('www.', '').strip('/')
+        if not force:
+            to_remove = ['http://', 'https://', 'www.']
 
-        if clean_current == clean_new:
-            return False
+            clean_current = self.driver.current_url
+            clean_new = url
+
+            for _to_remove in to_remove:
+                clean_current = clean_current.replace(_to_remove, '')
+                clean_new = clean_new.replace(_to_remove, '')
+
+            if clean_current.strip('/') == clean_new.strip('/'):
+                return False
 
         self.driver.get(url)
 
@@ -588,6 +596,15 @@ class Firefox:
 
             return False
 
+    def quit(self) -> bool:
+        try:
+            self.driver.quit()
+
+            return True
+        except Exception as e:
+            print('Error - Firefox: quit() - ', e)
+
+            return False
 
     # LEGACY
     def scroll_to_bottom(self) -> None:
@@ -615,9 +632,9 @@ class Firefox:
 
     def __del__(self):
         try:
-            self.driver.quit()
-        except:
-            pass
+            self.quit()
+        except Exception as e:
+            print('Error - Firefox: __del__() - ', e)
 
 
     # ------------------------------------------------------- Private methods -------------------------------------------------------- #
